@@ -30,9 +30,11 @@ class Maskbit(enum.Flag):
 
     @property
     def active_bits(self):
-        """Returns a list of flags that match the value."""
+        """Returns a list of non-combination flags that match the value."""
 
-        return [bit for bit in self.__class__ if bit.value & self.value]
+        return [bit for bit in self.__class__
+                if ((bit.value & self.value) and
+                    bin(bit.value).count('1') == 1)]
 
 
 COMMAND_STATUS_TO_CODE = {
@@ -77,7 +79,7 @@ class CommandStatus(Maskbit):
     def is_combination(self):
         """Returns True if a flag is a combination."""
 
-        if bin(self).count('1') > 1:
+        if bin(self.value).count('1') > 1:
             return True
         return False
 
@@ -188,7 +190,7 @@ class StatusMixIn(object):
         return self._status
 
     @status.setter
-    def status(self, value):  # pragma: no cover
+    def status(self, value):
         """Sets the status."""
 
         if value != self._status:
@@ -197,18 +199,12 @@ class StatusMixIn(object):
             if self.watcher is not None:
                 self.watcher.set()
 
-    async def wait_for_status(self, value, loop=None):
+    async def wait_for_status(self, value):
         """Awaits until the status matches ``value``."""
 
         if self.status == value:
             return
 
-        if loop is None:
-            if hasattr(self, 'loop') and self.loop is not None:
-                loop = self.loop
-            else:
-                loop = asyncio.get_event_loop()
-
         self.watcher = asyncio.Event()
 
         while self.status != value:
@@ -303,7 +299,7 @@ def format_value(value):
 
     if isinstance(value, str):
         if ' ' in value and not (value.startswith('\'') or value.startswith('"')):
-            value = json.dumps(value)
+            value = escape(value)
     elif isinstance(value, bool):
         value = 'T' if value else 'F'
     elif isinstance(value, (tuple, list)):
